#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class AuxDevicesMgt(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AuxDevicesMgt
                | 
                | INTERFACE : DNBIAAuxDevicesMgt
                | DESCRIPTION This allows add/remove and get/set of aux devices for a
                | robot
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.aux_devices_mgt = com_object

    def define_aux_devices(self, i_aux_device_obj: AnyObject, i_aux_device_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DefineAuxDevices(AnyObject iAuxDeviceObj,
                | DNBAuxilliaryDeviceType iAuxDeviceType)
                | 
                |     Add a aux device to the robot.
                | 
                |     Parameters:
                | 
                |         iAuxDeviceObj
                |             This parameter should be the device to add as aux device.
                |             
                |         iAuxDeviceType
                |             This parameter should be the type of aux device. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param AnyObject i_aux_device_obj:
        :param int i_aux_device_type: enum dnb_auxilliary_device_type
        :rtype: None
        """
        return self.aux_devices_mgt.DefineAuxDevices(i_aux_device_obj.com_object, i_aux_device_type)

    def get_all_aux_devices(self, o_aux_device_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllAuxDevices(CATSafeArrayVariant oAuxDeviceList)
                | 
                |     Get all aux devices defined for the robot.
                | 
                |     Parameters:
                | 
                |         oAuxDeviceList
                |             This outer parameter contains list of aux devices.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param tuple o_aux_device_list:
        :rtype: None
        """
        return self.aux_devices_mgt.GetAllAuxDevices(o_aux_device_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_aux_devices'
        # # vba_code = """
        # # Public Function get_all_aux_devices(aux_devices_mgt)
        # #     Dim oAuxDeviceList (2)
        # #     aux_devices_mgt.GetAllAuxDevices oAuxDeviceList
        # #     get_all_aux_devices = oAuxDeviceList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_aux_devices(self, i_aux_device_num: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAuxDevices(long iAuxDeviceNum) As AnyObject
                | 
                |     Get the aux device given the the index.
                | 
                |     Parameters:
                | 
                |         iAuxDeviceNum
                |             This parameter should be the index of the aux device. Valid values
                |             are from 1 to nbAuxDevices. 
                |         oAuxDevice
                |             This outer parameter contains aux device at the given index
                |             iAuxDeviceNum. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int i_aux_device_num:
        :rtype: AnyObject
        """
        return AnyObject(self.aux_devices_mgt.GetAuxDevices(i_aux_device_num))

    def get_aux_devices_type(self, i_aux_device_num: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAuxDevicesType(long iAuxDeviceNum) As
                | DNBAuxilliaryDeviceType
                | 
                |     Get the aux device given the the index.
                | 
                |     Parameters:
                | 
                |         iAuxDeviceNum
                |             This parameter should be the index of the aux device. Valid values
                |             are from 1 to nbAuxDevices. 
                |         oAuxDeviceType
                |             This outer parameter contains aux device type for the aux device at
                |             the given index iAuxDeviceNum. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int i_aux_device_num:
        :return: enum dnb_auxilliary_device_type
        :rtype: int
        """
        return self.aux_devices_mgt.GetAuxDevicesType(i_aux_device_num)

    def get_nb_aux_devices(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNbAuxDevices() As long
                | 
                |     Get the number of aux devices for the robot.
                | 
                |     Parameters:
                | 
                |         nbAuxDevices
                |             This outer parameter contains the number of aux devices.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: int
        """
        return self.aux_devices_mgt.GetNbAuxDevices()

    def remove_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAll()
                | 
                |     Remove all the aux devices defined for the robot.
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: None
        """
        return self.aux_devices_mgt.RemoveAll()

    def remove_aux_devices_by_position(self, i_aux_device_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAuxDevicesByPosition(long iAuxDeviceNum)
                | 
                |     Remove the aux device at the given index.
                | 
                |     Parameters:
                | 
                |         iAuxDeviceNum
                |             This parameter should be the index of the aux device to be removed.
                |             Valid values are from 1 to nbAuxDevices. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int i_aux_device_num:
        :rtype: None
        """
        return self.aux_devices_mgt.RemoveAuxDevicesByPosition(i_aux_device_num)

    def __repr__(self):
        return f'AuxDevicesMgt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class PSPPartConnector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspPartConnector
                | 
                | Represent the Part Connector to manage the technological data on
                | connectors.
                | Role: To access the technological data on connectors.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_part_connector = com_object

    @property
    def align_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AlignType() As CatPspIDLPartConnectorType (Read
                | Only)
                | 
                |     Returns the alignment type for this connector.
                | 
                |     See also:
                |         CatPspIDLPartConnectorType
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As CatPspIDLPartConnectorType
                |           ...
                |          objArg1 = objThisIntf.AlignType

        :return: enum cat_psp_idl_part_connector_type
        :rtype: int
        """

        return self.psp_part_connector.AlignType

    @property
    def attribute_names(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttributeNames() As PspListOfBSTRs
                | 
                |     Returns or sets a list of attribute names associated with this
                |     connector.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim ojArg1 As PspListOfBSTRs
                |           ...
                |          Set ojArg1 = objThisIntf.AttributeNames

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_part_connector.AttributeNames)

    @attribute_names.setter
    def attribute_names(self, value: PSPListOfBSTRs):
        """
        :param PSPListOfBSTRs value:
        """

        self.psp_part_connector.AttributeNames = value

    @property
    def clock_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ClockType() As CatPspIDLPartConnectorType (Read
                | Only)
                | 
                |     Returns the clocking type (how symmetric this end is) for this
                |     connector.
                | 
                |     See also:
                |         CatPspIDLPartConnectorType
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As CatPspIDLPartConnectorType
                |           ...
                |          objArg1 = objThisIntf.ClockType

        :return: enum cat_psp_idl_part_connector_type
        :rtype: int
        """

        return self.psp_part_connector.ClockType

    @property
    def face_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FaceType() As CatPspIDLPartConnectorType (Read
                | Only)
                | 
                |     Returns the face type (normal or "transparent" support) for this
                |     connector.
                | 
                |     Parameters:
                | 
                |         oFaceType
                |             The face type. 
                | 
                |     See also:
                |         CatPspIDLPartConnectorType
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As CatPspIDLPartConnectorType
                |           ...
                |          Set objArg1 = objThisIntf.FaceType

        :return: enum cat_psp_idl_part_connector_type
        :rtype: int
        """

        return self.psp_part_connector.FaceType

    def get_alignment_connector(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAlignmentConnector() As Reference
                | 
                |     Returns the Alignmnet connector.
                | 
                |     Parameters:
                | 
                |         oCntr
                |             Alignment connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |           ...
                |          Set objArg1 = objThisIntf.GetAlignmentConnector

        :rtype: Reference
        """
        return Reference(self.psp_part_connector.GetAlignmentConnector())

    def get_alignment_direction(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAlignmentDirection(Product iRelAxis) As
                | PspListOfDoubles
                | 
                |     Retrieves the alignment direction outward normal to the face place
                |     position.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             the relative axis object (Nothing means relative to parent)
                |             
                |         oAlignmentDirection
                |             Three double values stand for X,Y,Z components of the alignment
                |             vector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetAlignmentVector (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_part_connector.GetAlignmentDirection(i_rel_axis.com_object))

    def get_connector_math_plane(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConnectorMathPlane(Product iRelAxis) As
                | PspListOfDoubles
                | 
                |     Returns the 9 doubles values for plane contains the connector position
                |     (plane origin), alignment direction (plane z-axis), and the up direction (plane
                |     y-axis). Nine double values stand for plane origin, and the two normalized
                |     vectors
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis object (Nothing means relative to parent).
                |
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetConnectorMathPlane (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_part_connector.GetConnectorMathPlane(i_rel_axis.com_object))

    def get_datum_connector(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDatumConnector() As Reference
                | 
                |     Returns the Datum connector.
                | 
                |     Parameters:
                | 
                |         oCntr
                |             Orientation connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |           ...
                |          Set objArg1 = objThisIntf.GetDatumConnector

        :rtype: Reference
        """
        return Reference(self.psp_part_connector.GetDatumConnector())

    def get_face_connector(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFaceConnector() As Reference
                | 
                |     Returns the face connector.
                | 
                |     Parameters:
                | 
                |         oCntr
                |             Face connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |           ...
                |          Set objArg1 = objThisIntf.GetFaceConnector

        :rtype: Reference
        """
        return Reference(self.psp_part_connector.GetFaceConnector())

    def get_orientation_connector(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOrientationConnector() As Reference
                | 
                |     Get Orientation connector.
                | 
                |     Parameters:
                | 
                |         oCntr
                |             Orientation connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |           ...
                |          Set objArg1 = objThisIntf.GetOrientationConnector

        :rtype: Reference
        """
        return Reference(self.psp_part_connector.GetOrientationConnector())

    def get_position(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPosition(Product iRelAxis) As PspListOfDoubles
                | 
                |     Returns the Position of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis object (NULL means relative to parent).
                |             
                |         oPosition
                |             X-Y-Z coordinates of the part connector Three double values stand
                |             for x,y,z coordinates 
                | 
                |     Example:
                | 
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetPosition (objArg1 )

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_part_connector.GetPosition(i_rel_axis.com_object))

    def get_up_direction(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUpDirection(Product iRelAxis) As PspListOfDoubles
                | 
                |     Returns the UP direction of the connector.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis object (Nothing means relative to parent).
                |             
                |         oUpDirection
                |             The connector face plane. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.GetUpDirection (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_part_connector.GetUpDirection(i_rel_axis.com_object))

    def set_alignment_connector(self, i_align_cntr: Reference, ie_align_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAlignmentConnector(Reference iAlignCntr,
                | CatPspIDLPartConnectorType ieAlignType)
                | 
                |     Sets the Face connector.
                | 
                |     Parameters:
                | 
                |         iAlignCntr
                |             Alignment connector 
                |         ieAlignType
                |             Alignment connector Type 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |          Dim objArg2 As CatPspIDLPartConnectorType
                |           ...
                |          objThisIntf.SetFaceConnector objArg1, objArg2

        :param Reference i_align_cntr:
        :param int ie_align_type: enum cat_psp_idl_part_connector_type
        :rtype: None
        """
        return self.psp_part_connector.SetAlignmentConnector(i_align_cntr.com_object, ie_align_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_alignment_connector'
        # # vba_code = """
        # # Public Function set_alignment_connector(psp_part_connector)
        # #     Dim iAlignCntr (2)
        # #     psp_part_connector.SetAlignmentConnector iAlignCntr
        # #     set_alignment_connector = iAlignCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_datum_connector(self, i_datum_cntr: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDatumConnector(Reference iDatumCntr)
                | 
                |     Sets the Datum connector.
                | 
                |     Parameters:
                | 
                |         iDatumCntr
                |             Datum connector. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |           ...
                |          objThisIntf.SetDatumConnector objArg1

        :param Reference i_datum_cntr:
        :rtype: None
        """
        return self.psp_part_connector.SetDatumConnector(i_datum_cntr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_datum_connector'
        # # vba_code = """
        # # Public Function set_datum_connector(psp_part_connector)
        # #     Dim iDatumCntr (2)
        # #     psp_part_connector.SetDatumConnector iDatumCntr
        # #     set_datum_connector = iDatumCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_face_connector(self, i_face_cntr: Reference, ie_face_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFaceConnector(Reference iFaceCntr,
                | CatPspIDLPartConnectorType ieFaceType)
                | 
                |     Sets Face connector.
                | 
                |     Parameters:
                | 
                |         iFaceCntr
                |             Face connector 
                |         ieFaceType
                |             Face connector Type 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |          Dim objArg2 As CatPspIDLPartConnectorType
                |           ...
                |          objThisIntf.SetFaceConnector objArg1, objArg2

        :param Reference i_face_cntr:
        :param int ie_face_type: enum cat_psp_idl_part_connector_type
        :rtype: None
        """
        return self.psp_part_connector.SetFaceConnector(i_face_cntr.com_object, ie_face_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_face_connector'
        # # vba_code = """
        # # Public Function set_face_connector(psp_part_connector)
        # #     Dim iFaceCntr (2)
        # #     psp_part_connector.SetFaceConnector iFaceCntr
        # #     set_face_connector = iFaceCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_orientation_connector(self, i_orient_cntr: Reference, ie_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOrientationConnector(Reference iOrientCntr,
                | CatPspIDLPartConnectorType ieOrientation)
                | 
                |     Sets Face connector.
                | 
                |     Parameters:
                | 
                |         iOrientCntr
                |             Alignment connector 
                |         ieOrientation
                |             Orientation connector Type 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPartConnector
                |          Dim objArg1 As Reference
                |          Dim objArg2 As CatPspIDLPartConnectorType
                |           ...
                |          objThisIntf.SetOrientationConnector objArg1, objArg2

        :param Reference i_orient_cntr:
        :param int ie_orientation: enum cat_psp_idl_part_connector_type
        :rtype: None
        """
        return self.psp_part_connector.SetOrientationConnector(i_orient_cntr.com_object, ie_orientation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_orientation_connector'
        # # vba_code = """
        # # Public Function set_orientation_connector(psp_part_connector)
        # #     Dim iOrientCntr (2)
        # #     psp_part_connector.SetOrientationConnector iOrientCntr
        # #     set_orientation_connector = iOrientCntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPPartConnector(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_standard_pos_strategy_parameters import SFMStandardPosStrategyParameters
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class SFMPositioningStrategyManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmPositioningStrategyManager
                | 
                | Gets CATIASfmPositioningStrategyManager.
                | Use this Manager to GetAvailablePositioningStrategies &
                | GetPositioningStrategyParams.
                | 
                | Example:
                |     Get the Manager from factory.
                | 
                |       'Retrieve the Factory
                |       Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |       'Retrieve the Position Strategy Manager
                |       Dim ObjSfmPosStrategyMgr  As
                |       SfmPositioningStrategyManager
                |       Set ObjSfmPosStrategyMgr  = Factory.GetOpeningMgr(Part1, "SfmPositioningStrategyManager")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_positioning_strategy_manager = com_object

    def get_available_positioning_strategies(self, o_list_strategy_names: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAvailablePositioningStrategies(CATSafeArrayVariant
                | oListStrategyNames)
                | 
                |     Get The list of Available Position Strategies.
                | 
                |     Parameters:
                | 
                |         oListStrategyNames
                |             [out] List of Strategies. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             Gets Available Positoning Strategies from Position Strategy
                |             Manager.
                | 
                |               'Retrieve the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               'Retrieve the Position Strategy Manager
                |               Dim ObjSfmPosStrategyMgr As
                |               SfmPositioningStrategyManager
                |               Set ObjSfmPosStrategyMgr = Factory.GetOpeningMgr(Part1, "SfmPositioningStrategyManager")
                |               'Get The List of Available Strategies
                |               Dim oListStrategies() As Variant
                |               ObjSfmPosStrategyMgr.GetAvailablePositioningStrategies
                |               oListStrategies
                |               'Display The List of Available Strategies
                |               Dim NbOfStrategies As Long
                |               NbOfStrategies = UBound(oListStrategies)
                |               Display List of Strategies
                |               For i = 0 To NbOfStrategies
                |               MsgBox oListStrategies(i)
                |               Next

        :param tuple o_list_strategy_names:
        :rtype: cat_variant
        """
        return self.sfm_positioning_strategy_manager.GetAvailablePositioningStrategies(o_list_strategy_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_available_positioning_strategies'
        # # vba_code = """
        # # Public Function get_available_positioning_strategies(sfm_positioning_strategy_manager)
        # #     Dim oListStrategyNames (2)
        # #     sfm_positioning_strategy_manager.GetAvailablePositioningStrategies oListStrategyNames
        # #     get_available_positioning_strategies = oListStrategyNames
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_positioning_strategy_params(self, i_pos_strategy_name: str) -> SFMStandardPosStrategyParameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPositioningStrategyParams(CATBSTR iPosStrategyName) As
                | SfmStandardPosStrategyParameters
                | 
                |     Get The list of Available Position Strategies Parameters, depending on
                |     Strategy Name. See CATIASfmStandardPosStrategyParameters for
                |     details
                | 
                |     Parameters:
                | 
                |         iPosStrategyName
                |             [in] Name of Strategy. 
                |         oListPosParams
                |             [out] List of parameters. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             The Example Demonstrates how to get position strategy parameters
                |             for "CATSfmPosMidDistMidDist".
                | 
                |               'Retrieve the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               'Retrieve the Position Strategy Manager
                |               Dim ObjSfmPosStrategyMgr As
                |               SfmPositioningStrategyManager
                |               Set ObjSfmPosStrategyMgr = Factory.GetOpeningMgr(Part1, "SfmPositioningStrategyManager")
                |               Dim PositionStrategyParms As
                |               SfmStandardPosStrategyParameters
                |               Set PositionStrategyParms = ObjSfmPosStrategyMgr.GetPositioningStrategyParams("CATSfmPosMidDistMidDist")

        :param str i_pos_strategy_name:
        :rtype: SFMStandardPosStrategyParameters
        """
        return SFMStandardPosStrategyParameters(
            self.sfm_positioning_strategy_manager.GetPositioningStrategyParams(
                i_pos_strategy_name
            )
        )

    def __repr__(self):
        return f'SFMPositioningStrategyManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature
from pycatia.manufacturing_interfaces.manufacturing_tool_motion import ManufacturingToolMotion
from pycatia.manufacturing_interfaces.manufacturing_tool_motions import MFGToolMotions
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingOperation(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingOperation
                | 
                | ManufacturingOperation defines a set of methods.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_operation = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR
                | 
                |     Return the Comment linked to a Manufacturing Operation.
                | 
                |     Example:
                |         The following example returns the Comment ThisComment linked to a
                |         manufacturing operation CurrentMo
                | 
                |          Set ThisComment = CurrentMo.Comment

        :rtype: str
        """

        return self.manufacturing_operation.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_operation.Comment = value

    def add_clearance(self, i_type_macro: str, i_a: float, i_b: float, i_c: float, i_d: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddClearance(CATBSTR iTypeMacro,
                | double iA,
                | double iB,
                | double iC,
                | double iD)
                | 
                |     Add a 'clearance to a plane' path to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example add a path (clerarance) on approach macro of
                |         operation
                | 
                |          call Operation.AddClearance("Approach", A, B, C, D)

        :param str i_type_macro:
        :param float i_a:
        :param float i_b:
        :param float i_c:
        :param float i_d:
        :rtype: None
        """
        return self.manufacturing_operation.AddClearance(i_type_macro, i_a, i_b, i_c, i_d)

    def add_distance_along_aline_motion(
            self,
            i_type: str,
            i_distance: float,
            i_line: AnyObject,
            i_product: Product
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDistanceAlongAlineMotion(CATBSTR iType,
                | double iDistance,
                | AnyObject iLine,
                | Product iProduct)
                | 
                |     Add a path 'distance along a line' to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example add a path (distance along a line) on the
                |         approach group of path of the Linking macro of
                |         operation
                | 
                |          call Operation.AddDistanceAlongAlineMotion("LinkingApproach",
                |          distance, iLine, iProduct)

        :param str i_type:
        :param float i_distance:
        :param AnyObject i_line:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_operation.AddDistanceAlongAlineMotion(
            i_type,
            i_distance,
            i_line.com_object,
            i_product.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_distance_along_aline_motion'
        # # vba_code = """
        # # Public Function add_distance_along_aline_motion(manufacturing_operation)
        # #     Dim iType (2)
        # #     manufacturing_operation.AddDistanceAlongAlineMotion iType
        # #     add_distance_along_aline_motion = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_distance_along_aline_motion_feed(
            self,
            i_type: str,
            i_distance: float,
            i_line: AnyObject,
            i_product: Product,
            i_feedrate_type: str,
            i_feedrate_value: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDistanceAlongAlineMotionFeed(CATBSTR iType,
                | double iDistance,
                | AnyObject iLine,
                | Product iProduct,
                | CATBSTR iFeedrateType,
                | double iFeedrateValue)
                | 
                |     Add a path 'distance along a line' with Feedrate info to a Manufacturing
                |     Operation.
                | 
                |     Parameters:
                | 
                |         iFeedrateType
                |             Legal values: iFeedrateType can be
                | 
                |             "None"
                |             "Machining"
                |             "Approach"
                |             "Retract"
                |             "RAPID"
                |             "Local"
                | 
                |         iFeedrateValue
                |             feedrate Value in MKS units : m/s if linear feedrate, or m/turn if angular feedrate (take into account only if iFeedrateType = "Local") 
                | 
                |     Example:
                |         The following example add a path (distance along a line) on the
                |         approach group of path of the Linking macro of
                |         operation
                | 
                |          call Operation.AddDistanceAlongAlineMotionFeed("LinkingApproach",
                |          distance, iLine, iProduct, iFeedrateType,
                |          iFeedrateValue)

        :param str i_type:
        :param float i_distance:
        :param AnyObject i_line:
        :param Product i_product:
        :param str i_feedrate_type:
        :param float i_feedrate_value:
        :rtype: None
        """
        return self.manufacturing_operation.AddDistanceAlongAlineMotionFeed(
            i_type,
            i_distance,
            i_line.com_object,
            i_product.com_object,
            i_feedrate_type,
            i_feedrate_value
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_distance_along_aline_motion_feed'
        # # vba_code = """
        # # Public Function add_distance_along_aline_motion_feed(manufacturing_operation)
        # #     Dim iType (2)
        # #     manufacturing_operation.AddDistanceAlongAlineMotionFeed iType
        # #     add_distance_along_aline_motion_feed = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_distance_along_axis(self, i_type: str, i_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDistanceAlongAxis(CATBSTR iType,
                | double iDistance)
                | 
                |     Add a path 'distance along axis' to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example add a path (distance along axis) on the approach
                |         group of path of the Linking macro of operation
                | 
                |          call Operation.AddDistanceAlongAxis("LinkingApproach",
                |          distance)

        :param str i_type:
        :param float i_distance:
        :rtype: None
        """
        return self.manufacturing_operation.AddDistanceAlongAxis(i_type, i_distance)

    def add_distance_along_axis_feed(
            self,
            i_type: str,
            i_distance: float,
            i_feedrate_type: str,
            i_feedrate_value: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDistanceAlongAxisFeed(CATBSTR iType,
                | double iDistance,
                | CATBSTR iFeedrateType,
                | double iFeedrateValue)
                | 
                |     Add a path 'distance along axis' with Feedrate info to a Manufacturing
                |     Operation.
                | 
                |     Parameters:
                | 
                |         iFeedrateType
                |             Legal values: iFeedrateType can be
                | 
                |             "None"
                |             "Machining"
                |             "Approach"
                |             "Retract"
                |             "RAPID"
                |             "Local"
                | 
                |         iFeedrateValue
                |             feedrate Value in MKS units : m/s if linear feedrate, or m/turn if
                |             angular feedrate (take into account only if iFeedrateType = "Local")
                | 
                |     Example:
                |         The following example add a path (distance along axis) on the approach
                |         group of path of the Linking macro of operation
                | 
                |          call Operation.AddDistanceAlongAxisFeed("LinkingApproach", distance,
                |          iFeedrateType, iFeedrateValue)

        :param str i_type:
        :param float i_distance:
        :param str i_feedrate_type:
        :param float i_feedrate_value:
        :rtype: None
        """
        return self.manufacturing_operation.AddDistanceAlongAxisFeed(
            i_type,
            i_distance,
            i_feedrate_type,
            i_feedrate_value
        )

    def add_goto_horizontal(self, i_type_macro: str, i_distance: float, i_angle1: float, i_angle2: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddGotoHorizontal(CATBSTR iTypeMacro,
                | double iDistance,
                | double iAngle1,
                | double iAngle2)
                | 
                |     Add a path 'goto horizontal' to a Manufacturing Operation.
                | 
                |     Example:
                |         The following example add a path (goto horizontal) on approach macro of
                |         operation
                | 
                |          call Operation.AddGotoHorizontal("Approach", distance, angle1,
                |          angle2)

        :param str i_type_macro:
        :param float i_distance:
        :param float i_angle1:
        :param float i_angle2:
        :rtype: None
        """
        return self.manufacturing_operation.AddGotoHorizontal(i_type_macro, i_distance, i_angle1, i_angle2)

    def add_motion_go_to_a_point(self, i_type_macro: str, i_point: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMotionGoToAPoint(CATBSTR iTypeMacro,
                | AnyObject iPoint,
                | Product iProduct)
                | 
                |     Add a path 'goto a point' to a Manufacturing Operation.
                | 
                |     Example:
                |         The following example add a path (goto a point ) on approach macro of
                |         operation
                | 
                |          call Operation.AddMotionGoToAPoint("Approach", iPoint, iProduct
                |          )

        :param str i_type_macro:
        :param AnyObject i_point:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_operation.AddMotionGoToAPoint(i_type_macro, i_point.com_object, i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_motion_go_to_a_point'
        # # vba_code = """
        # # Public Function add_motion_go_to_a_point(manufacturing_operation)
        # #     Dim iTypeMacro (2)
        # #     manufacturing_operation.AddMotionGoToAPoint iTypeMacro
        # #     add_motion_go_to_a_point = iTypeMacro
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_motion_go_to_a_point_feed(
            self,
            i_type_macro: str,
            i_point: AnyObject,
            i_product: Product,
            i_feedrate_type: str,
            i_feedrate_value: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMotionGoToAPointFeed(CATBSTR iTypeMacro,
                | AnyObject iPoint,
                | Product iProduct,
                | CATBSTR iFeedrateType,
                | double iFeedrateValue)
                | 
                |     Add a path 'goto a point' with Feedrate info to a Manufacturing
                |     Operation.
                | 
                |     Parameters:
                | 
                |         iFeedrateType
                |             Legal values: iFeedrateType can be
                | 
                |             "None"
                |             "Machining"
                |             "Approach"
                |             "Retract"
                |             "RAPID"
                |             "Local"
                | 
                |         iFeedrateValue
                |             feedrate Value in MKS units : m/s if linear feedrate, or m/turn if
                |             angular feedrate (take into account only if iFeedrateType = "Local")
                | 
                |     Example:
                |         The following example add a path (goto a point ) on approach macro of
                |         operation
                | 
                |          call Operation.AddMotionGoToAPointFeed("Approach", iPoint, iProduct,
                |          iFeedrateType, iFeedrateValue)

        :param str i_type_macro:
        :param AnyObject i_point:
        :param Product i_product:
        :param str i_feedrate_type:
        :param float i_feedrate_value:
        :rtype: None
        """
        return self.manufacturing_operation.AddMotionGoToAPointFeed(
            i_type_macro,
            i_point.com_object,
            i_product.com_object,
            i_feedrate_type,
            i_feedrate_value
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_motion_go_to_a_point_feed'
        # # vba_code = """
        # # Public Function add_motion_go_to_a_point_feed(manufacturing_operation)
        # #     Dim iTypeMacro (2)
        # #     manufacturing_operation.AddMotionGoToAPointFeed iTypeMacro
        # #     add_motion_go_to_a_point_feed = iTypeMacro
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_motion_to_a_plane(self, i_type_macro: str, i_mode: int, i_plane: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMotionToAPlane(CATBSTR iTypeMacro,
                | short iMode,
                | AnyObject iPlane,
                | Product iProduct)
                | 
                |     Add a path 'goto a plane with axial or perpendicular move' to a
                |     Manufacturing Operation.
                | 
                |     Example:
                |         The following example add a path (goto a plane with axial move ) on
                |         approach macro of operation
                | 
                |          call Operation.AddMotionToAPlane("Approach", 1, iPlane,
                |          iProduct)
                | 
                |     Example:
                |         The following example add a path (goto a plane with perpendicular move
                |         ) on approach macro of operation
                | 
                |          call Operation.AddMotionToAPlane("Approach", 0, iPlane,
                |          iProduct)

        :param str i_type_macro:
        :param int i_mode:
        :param AnyObject i_plane:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_operation.AddMotionToAPlane(
            i_type_macro,
            i_mode,
            i_plane.com_object,
            i_product.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_motion_to_a_plane'
        # # vba_code = """
        # # Public Function add_motion_to_a_plane(manufacturing_operation)
        # #     Dim iTypeMacro (2)
        # #     manufacturing_operation.AddMotionToAPlane iTypeMacro
        # #     add_motion_to_a_plane = iTypeMacro
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_pp_words(self, i_type_macro: str, i_pp_words: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPPWords(CATBSTR iTypeMacro,
                | CATBSTR iPPWords)
                | 
                |     Add a path 'PP Words' to a Manufacturing Operation.
                | 
                |     Example:
                |         The following example add a path (PP Words) on the retract group of
                |         path of the Linking macro of operation
                | 
                |          call Operation.AddPPWords("LinkingRetract", "PP Words
                |          example")

        :param str i_type_macro:
        :param str i_pp_words:
        :rtype: None
        """
        return self.manufacturing_operation.AddPPWords(i_type_macro, i_pp_words)

    def get_a_geometric_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAGeometricAttribute(CATBSTR iAttribut) As
                | Parameter
                | 
                |     Retrieve a Geometric Attribute of a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example retrieves in Offset the attribute OriginOffset of
                |         Manufacturing Operation firstOperation
                | 
                |          Set Offset = firstOperation.GetAttribute(OriginOffset)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_operation.GetAGeometricAttribute(i_attribute))

    def get_an_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retrieve the Attribute of a Manufacturing Operation.
                | 
                |     Example:
                |         The following example Retrieves in RapidFeed the attribute MfgRapidFeed
                |         of Manufacturing Operation firstOperation
                | 
                |          Set RapidFeed = firstOperation.GetAttribute(MfgRapidFeed)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_operation.GetAnAttribute(i_attribute))

    def get_feature(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFeature() As AnyObject
                | 
                |     Retrieve the Machinable Feature asociated to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in firstOperation the machinable
                |         feature Feature
                | 
                |          call firstOperation.GetFeature(Feature)

        :rtype: AnyObject
        """
        return AnyObject(self.manufacturing_operation.GetFeature())

    def get_feed_speed_auto_update(self, i_type: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFeedSpeedAutoUpdate(CATBSTR iType) As boolean
                | 
                |     Returns the Auto Update status for Feed Rate or Spindle
                |     Speed.
                | 
                |     Parameters:
                | 
                |         iType
                |             Determines if the method works on Feed Rate or Spindle Speed Legal
                |             values: iType can be
                | 
                |                 "FEEDRATE"
                |                 "SPINDLESPEED"
                | 
                |     Returns:
                |         oAutoUpdate Auto update status
                | 
                |             Example:
                |             The following example checks the status of AutoUpdate for Feed
                |             Rate
                |             Dim isAutoUpdateEnabled As Boolean
                |             isAutoUpdateEnabled = firstOperation.GetFeedSpeedAutoUpdate("FEEDRATE")

        :param str i_type:
        :rtype: bool
        """
        return self.manufacturing_operation.GetFeedSpeedAutoUpdate(i_type)

    def get_list_of_tool_motions(self) -> MFGToolMotions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetListOfToolMotions() As MfgToolMotions
                | 
                |     Give a list of Manufacturing ToolMotion contained by a sequential
                |     operation.
                | 
                |     See interface CATIAMfgToolMotions for methods available on the
                |     list
                |         The following example extract the tool motions of operation SeqMO in
                |         the MfgToolMotions 
                |         list TMList2 .
                | 
                |          
                |         Example:
                |         Dim TMList2 As MfgToolMotions
                |         Set TMList2 = SeqMO.GetListOfToolMotions
                |         Dim Test2 As ManufacturingToolMotion
                |         Set Test2 = TMList2.GetElement(1)

        :return: MfgToolMotions
        :rtype: MFGToolMotions
        """
        return MFGToolMotions(self.manufacturing_operation.GetListOfToolMotions())

    def get_manufacturing_feature(self) -> ManufacturingFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManufacturingFeature() As ManufacturingFeature
                | 
                |     Retrieve the Manufacturing Feature asociated to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in firstOperation the manufacturing
                |         feature Feature
                | 
                |          Set Feature = firstOperation.GetManufacturingFeature

        :rtype: ManufacturingFeature
        """
        return ManufacturingFeature(self.manufacturing_operation.GetManufacturingFeature())

    def get_mfg_aparam_top_pln(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgAparamTopPln() As double
                | 
                |     Retrieve the Equation of the Top Plane of a Pocket
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in A,B,C,D the equation Ax + By + Cz + D = 0
                |         of Manufacturing Pocket Operation firstOperation
                | 
                |          Dim A
                |          Set A = firstOperation.GetMfgBparamTopPln

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgAparamTopPln()

    def get_mfg_axial_feature_diameter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgAxialFeatureDiameter() As double
                | 
                |     Retrieve the diameter of an axial manufacturing feature.
                | 
                |     Example:
                |         The following example Retrieves in Diam the diameter of the axial
                |         manufacturing feature linked to the operation
                |         firstOperation
                | 
                |          Dim Diam 
                |          Set Diam = firstOperation.GetMfgAxialFeatureDiameter

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgAxialFeatureDiameter()

    def get_mfg_bparam_top_pln(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgBparamTopPln() As double
                | 
                |     Retrieve the Equation of the Top Plane of a Pocket
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in A,B,C,D the equation Ax + By + Cz + D = 0
                |         of Manufacturing Pocket Operation firstOperation
                | 
                |          Dim B
                |          Set B = firstOperation.GetMfgBparamTopPln

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgBparamTopPln()

    def get_mfg_cparam_top_pln(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgCparamTopPln() As double
                | 
                |     Retrieve the Equation of the Top Plane of a Pocket
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in A,B,C,D the equation Ax + By + Cz + D = 0
                |         of Manufacturing Pocket Operation firstOperation
                | 
                |          Dim C
                |          Set C = firstOperation.GetMfgCparamTopPln

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgCparamTopPln()

    def get_mfg_dparam_top_pln(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgDparamTopPln() As double
                | 
                |     Retrieve the Equation of the Top Plane of a Pocket
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in A,B,C,D the equation Ax + By + Cz + D = 0
                |         of Manufacturing Pocket Operation firstOperation
                | 
                |          Dim D
                |          Set D = firstOperation.GetMfgDparamTopPln

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgDparamTopPln()

    def get_mfg_feature_position(self, io_position: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMfgFeaturePosition(CATSafeArrayVariant ioPosition)
                | 
                |     Retrieve the Coordinate of the Reference Point of a Drill
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in X,Y,Z the coordinate (X,Y,Z) of the
                |         Reference Point of the Drill Operation firstOperation
                | 
                |          Dim oPositionArray(3) As CATSafeArrayVariant
                |          Call
                |          firstOperation.GetMfgFeaturePosition(oPositionArray)
                |          Assume this array is oPositionArray. It contains: 
                |
                |         oPositionArray[0],oPositionArray[1],oPositionArray[2]
                |          
                |             The X, Y, and Z direction vector components
                |
                |         Example:
                |          
                |             The following example returns in oPositionArray
                |              the coordinates of the feature position
                |
                |              Call firstOperation.GetMfgFeaturePosition(oCoord)
                |              x = oPositionArray[0]
                |              y = oPositionArray[1]
                |              z = oPositionArray[2]

        :param tuple io_position:
        :rtype: tuple
        """
        return self.manufacturing_operation.GetMfgFeaturePosition(io_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_mfg_feature_position'
        # # vba_code = """
        # # Public Function get_mfg_feature_position(manufacturing_operation)
        # #     Dim ioPosition (2)
        # #     manufacturing_operation.GetMfgFeaturePosition ioPosition
        # #     get_mfg_feature_position = ioPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_mfg_feature_x_position(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgFeatureXPosition() As double
                | 
                |     Retrieve the Coordinate of the Reference Point of a Drill
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in X,Y,Z the coordinate (X,Y,Z) of the
                |         Reference Point of the Drill Operation firstOperation
                | 
                |          Dim X
                |          X = firstOperation.GetMfgFeatureXPosition

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgFeatureXPosition()

    def get_mfg_feature_y_position(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgFeatureYPosition() As double
                | 
                |     Retrieve the Coordinate of the Reference Point of a Drill
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in X,Y,Z the coordinate (X,Y,Z) of the
                |         Reference Point of the Drill Operation firstOperation
                | 
                |          Dim Y
                |          Y = firstOperation.GetMfgFeatureYPosition

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgFeatureYPosition()

    def get_mfg_feature_z_position(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMfgFeatureZPosition() As double
                | 
                |     Retrieve the Coordinate of the Reference Point of a Drill
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in X,Y,Z the coordinate (X,Y,Z) of the
                |         Reference Point of the Drill Operation firstOperation
                | 
                |          Dim Z
                |          Z = firstOperation.GetMfgFeatureZPosition

        :rtype: float
        """
        return self.manufacturing_operation.GetMfgFeatureZPosition()

    def get_mfg_top_plane(self, o_a: float, o_b: float, o_c: float, o_d: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMfgTopPlane(double oA,
                | double oB,
                | double oC,
                | double oD)
                | 
                |     Retrieve the Equation of the Top Plane of a Pocket
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in A,B,C,D the equation Ax + By + Cz + D = 0
                |         of Manufacturing Pocket Operation firstOperation
                | 
                |          Call firstOperation.GetMfgTopPlane(A,B,C,D)

        :param float o_a:
        :param float o_b:
        :param float o_c:
        :param float o_d:
        :rtype: None
        """
        return self.manufacturing_operation.GetMfgTopPlane(o_a, o_b, o_c, o_d)

    def get_pattern(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPattern() As AnyObject
                | 
                |     Retrieve the Machining Pattern asociated to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example Retrieves in firstOperation the machining pattern
                |         Pattern
                | 
                |          Set Pattern = firstOperation.GetPattern

        :rtype: AnyObject
        """
        return AnyObject(self.manufacturing_operation.GetPattern())

    def get_radius_on_macro(self, i_macro_type: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRadiusOnMacro(CATBSTR iMacroType) As double
                | 
                |     Retrieves radius attribute on the circular elementary macro motion on
                |     CIRCULAR MILLING or THREAD MILLING operations ONLY.
                | 
                |     Parameters:
                | 
                |         iMacroType
                |             Legal values: iMacroType can be:
                | 
                |             "Approach", to get the radius on the Approach
                |             Macro
                |             "Retract", to get the radius on the Retract Macro
                |             "ReturnInALevelApproach", to get the radius on the Return in a
                |             level Macro (Approach)
                |             "ReturnInALevelRetract", to get the radius on the Return in a level
                |             Macro (Retract)
                |             "ReturnBetweenLevelsApproach", to get the radius on the Return
                |             between levels Macro (Approach)
                |             "ReturnBetweenLevelsRetract", to get the radius on the Return
                |             between levels Macro (Approach)
                | 
                |         oRadius
                |             Radius value. (expressed in millimeters) 
                | 
                |     Example:
                |         The following example retrieves the radius on the circular motion of
                |         the retract macro on the Circular Milling operation
                |         CircularMilling1
                | 
                |          dim RadValue as double
                |          RadValue = CircularMilling1.GetRadiusOnMacro("Retract")

        :param str i_macro_type:
        :rtype: float
        """
        return self.manufacturing_operation.GetRadiusOnMacro(i_macro_type)

    def get_relimiting_geometry(
            self,
            i_geometry_type: str,
            o_reference: AnyObject,
            o_product: AnyObject,
            o_offset: float,
            o_position: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRelimitingGeometry(CATBSTR iGeometryType,
                | AnyObject oReference,
                | AnyObject oProduct,
                | double oOffset,
                | CATBSTR oPosition)
                | 
                |     Retrieves start / end element on PROFILE CONTOURING operation
                |     ONLY.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be:
                | 
                |             "StartElement", to get the Start element on Profile
                |             Contouring
                |             "EndElement", to get the End element on Profile
                |             Contouring
                | 
                |         oReference
                |             The relimiting geometry. 
                |         oProduct
                |             Product containing the relimiting geometry. 
                |         oOffset
                |             Offset set on the relimiting geometry. (expressed in millimeters)
                |             
                |         oPosition
                |             Tool position set on the relimiting geometry.
                |             Legal values: oPosition can be:
                | 
                |             "IN"
                |             "ON"
                |             "OUT"
                | 
                |     Example:
                |         The following example gets the End relimiting element of the Profile
                |         Contouring operation Contouring1
                | 
                |          Call Contouring1.GetRelimitingGeometry("EndElement",RelimitingElement,PartMachined,Offset,Position)

        :param str i_geometry_type:
        :param AnyObject o_reference:
        :param AnyObject o_product:
        :param float o_offset:
        :param str o_position:
        :rtype: None
        """
        return self.manufacturing_operation.GetRelimitingGeometry(
            i_geometry_type,
            o_reference.com_object,
            o_product.com_object,
            o_offset,
            o_position
        )

    def get_start_point_geometry(
            self,
            o_geometry_position: str,
            o_reference: AnyObject,
            o_product: AnyObject,
            o_offset: float
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetStartPointGeometry(CATBSTR oGeometryPosition,
                | AnyObject oReference,
                | AnyObject oProduct,
                | double oOffset)
                | 
                |     Retrieves geometry and offset of a start point on POCKETING operation
                |     ONLY.
                | 
                |     Parameters:
                | 
                |         oGeometryPosition
                |             Legal values: oGeometryPosition can be:
                | 
                |             "Outside", if the start point is outside the pocket
                |             contour
                |             "Inside", if the start point is inside the pocket
                |             contour
                | 
                |         oReference
                |             The start point geometry. 
                |         oProduct
                |             Product containing the start point geometry. 
                |         oOffset
                |             Offset set on the start point. (expressed in
                |             millimeters)
                |             Offset has a meaning only if oGeometryPosition value is "Outside".
                |
                |     Example:
                |         The following example gets the Start point geometry on the Pocketing
                |         operation Pocketing1
                | 
                |          Call Pocketing1.GetStartPointGeometry(Position,Point1,Part,OffsetValue)

        :param str o_geometry_position:
        :param AnyObject o_reference:
        :param AnyObject o_product:
        :param float o_offset:
        :rtype: tuple
        """
        return self.manufacturing_operation.GetStartPointGeometry(
            o_geometry_position,
            o_reference.com_object,
            o_product.com_object,
            o_offset
        )

    def get_tool_gauge(self, o_min_tool_length: float, o_min_tool_gage: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolGage(double oMinToolLength,
                | double oMinToolGage)
                | 
                |     Retrieves the minimum tool cutting lentgh and the minimum tool gage
                |     length.
                | 
                |     Example:
                |         The following example Retrieves in MinToolLength and MinToolGage the
                |         values of tool of Manufacturing Operation Operation
                | 
                |          Call Operation.GetToolGage(MinToolLength,MinToolGage)

        :param float o_min_tool_length:
        :param float o_min_tool_gage:
        :rtype: None
        """
        return self.manufacturing_operation.GetToolGage(o_min_tool_length, o_min_tool_gage)

    def get_trajectory_end_point_coord(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTrajectoryEndPointCoord(CATSafeArrayVariant
                | oEndPoint)
                | 
                |     Retrieve the Machining Operation's trajectory end point.
                | 
                |     Example:
                |         The following example Retrieves in oEndPoint the end point of the
                |         Machining Operation Operation
                | 
                |          Dim oEndPoint(2)
                |          call Operation.GetTrajectoryEndPointCoord(oEndPoint)
                |          x = oEndPoint(0)
                |          y = oEndPoint(1)
                |          z = oEndPoint(2)

        :rtype: tuple
        """
        return self.manufacturing_operation.GetTrajectoryEndPointCoord()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_trajectory_end_point_coord'
        # # vba_code = """
        # # Public Function get_trajectory_end_point_coord(manufacturing_operation)
        # #     Dim oEndPoint (2)
        # #     manufacturing_operation.GetTrajectoryEndPointCoord oEndPoint
        # #     get_trajectory_end_point_coord = oEndPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_trajectory_start_point_coord(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTrajectoryStartPointCoord(CATSafeArrayVariant
                | oStartPoint)
                | 
                |     Retrieve the Machining Operation's trajectory start point.
                | 
                |     Example:
                |         The following example Retrieves in oStartPoint the start point of the
                |         Machining Operation Operation
                | 
                |          Dim oEndPoint(2)
                |          call
                |          Operation.GetTrajectoryStartPointCoord(oStartPoint)
                |          x = oStartPoint(0)
                |          y = oStartPoint(1)
                |          z = oStartPoint(2)

        :rtype: tuple
        """
        return self.manufacturing_operation.GetTrajectoryStartPointCoord()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_trajectory_start_point_coord'
        # # vba_code = """
        # # Public Function get_trajectory_start_point_coord(manufacturing_operation)
        # #     Dim oStartPoint (2)
        # #     manufacturing_operation.GetTrajectoryStartPointCoord oStartPoint
        # #     get_trajectory_start_point_coord = oStartPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_nc_output(self, i_type: str, i_nc_output_file: str, i_pp_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportNCOutput(CATBSTR iType,
                | CATBSTR iNCOutputFile,
                | CATBSTR iPPName)
                | 
                |     Import an NC File.
                | 
                |     Example:
                |         The following example imports after an operation Operation an NC File
                |         of type TYPE available in the file path PATH using the PP PPNAME if
                |         required.
                | 
                |          Call
                |          Operation.ImportNCOutputOnProgram(TYPE,PATH,PPNAME)

        :param str i_type:
        :param str i_nc_output_file:
        :param str i_pp_name:
        :rtype: None
        """
        return self.manufacturing_operation.ImportNCOutput(i_type, i_nc_output_file, i_pp_name)

    def insert_tool_motion(self, i_type: str, i_position: int) -> ManufacturingToolMotion:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func InsertToolMotion(CATBSTR iType,
                | short iPosition) As ManufacturingToolMotion
                | 
                |     Create, given its type, a Manufacturing ToolMotion inside a sequential
                |     operation.
                | 
                |         The available type for lathe sequential operation are : 
                |         for GoStandard and GoGo tool motion iType = MfgSeqMotionLatheGoStd 
                |         for GoDelta tool motion, iType = MfgSeqMotionLatheDelta 
                |         for Indirv tool motion, iType = MfgSeqMotionLatheIndirv 
                |         for Follow tool motion, iType = MfgSeqMotionLatheFollow 
                |         for PPWord tool motion, iType = MfgSeqMotionPPWord 
                |         The available type for prismatic sequential operation are : 
                |         for Goto Point tool motion, iType = MfgSeqMotionPoint 
                |         for Goto Position tool motion, iType = MfgSeqMotionPosition 
                |         for Goto Delta tool motion, iType = MfgSeqMotionDelta 
                |         iType type of the ToolMotion to be created iPosition rank in the
                |         operation list where the ToolMotion will be created 
                |         iPosition=0 means creation at the end of the list of tool motions
                |         oToolMotion the created ManufacturingToolMotion 
                |         The following example creates in ManufacturingOperation SeqMO
                |         
                |         which is a Lathe Sequential operation 
                |         the ManufacturingToolMotion ThisToolMotion of type
                |         MfgSeqMotionLatheGoStd at the first rank
                | 
                |          
                |         Example:
                |         Set SeqMO = Program1.AppendOperation("MfgLatheMfgSequentialOperation",1)
                |         Set ThisToolMotion = SeqMO.InsertToolMotion("MfgSeqMotionLatheGoStd",1)
                | 
                |         The following example creates in ManufacturingOperation SeqMO
                |         
                |         which is an Axial Point to Point sequential operation 
                |         the ManufacturingToolMotion ThisToolMotion of type MfgSeqMotionPoint at
                |         the first rank
                | 
                |          
                |         Example:
                |         Set SeqMO = Program1.AppendOperation("PointToPoint",1)
                |         Set ThisToolMotion = SeqMO.InsertToolMotion("MfgSeqMotionPoint",1)

        :param str i_type:
        :param int i_position:
        :rtype: ManufacturingToolMotion
        """
        return ManufacturingToolMotion(self.manufacturing_operation.InsertToolMotion(i_type, i_position))

    def is_geometrically_accessible_on_setup(self, i_manufacturing_setup: AnyObject) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsGeometricallyAccessibleOnSetup(AnyObject iManufacturingSetup) As
                | boolean
                | 
                |     Returns True if the Manufacturing Axial Operation is geometrically
                |     accessible on the given Manufacturing Setup.The Axial Operation must have a
                |     valid tool axis and a machine must be assigned to the Manufacturing Setup. If
                |     this is not the case, the method returns False.
                | 
                |     Parameters:
                | 
                |         iSetup
                |             The Manufacturing Setup gives the accessibility checking context :
                |             the part,the machine and the relative orientation of the part on the machine.
                | 
                |             Example:
                |                 The following example checks the accessibility of
                |                 firstOperation on firstSetup.
                | 
                |                  Dim isAccessible As Boolean
                |                  isAccessible = firstOperation.IsGeometricallyAccessibleOnSetup(firstSetup)

        :param AnyObject i_manufacturing_setup:
        :rtype: bool
        """
        return self.manufacturing_operation.IsGeometricallyAccessibleOnSetup(i_manufacturing_setup.com_object)

    def lock_activity(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LockActivty()
                | 
                |     Method is used for Locking and Unloking specific activity Call on
                |     ManufacturingOperation

        :rtype: None
        """
        return self.manufacturing_operation.LockActivty()

    def remove_relimiting_geometry(self, i_geometry_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveRelimitingGeometry(CATBSTR iGeometryType)
                | 
                |     Removes the geometry on relimiting element PROFILE CONTOURING operation
                |     ONLY.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be:
                | 
                |             "StartElement", to remove the Start element on Profile
                |             Contouring
                |             "EndElement", to remove the End element on Profile
                |             Contouring
                | 
                |     Example:
                |         The following example removes the End relimiting element of the Profile
                |         Contouring operation Contouring1
                | 
                |          Call
                |          Contouring1.RemoveRelimitingGeometry("EndElement")

        :param str i_geometry_type:
        :rtype: None
        """
        return self.manufacturing_operation.RemoveRelimitingGeometry(i_geometry_type)

    def remove_start_point_geometry(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveStartPointGeometry()
                | 
                |     Removes the start point element on POCKETING operation
                |     ONLY.
                | 
                |     Example:
                |         The following example removes the start point of the Pocketing
                |         operation Pocketing1
                | 
                |          Call Pocketing1.RemoveStartPointGeometry

        :rtype: None
        """
        return self.manufacturing_operation.RemoveStartPointGeometry()

    def set_feature(self, i_machinable_feature: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFeature(AnyObject iMachinableFeature)
                | 
                |     Associate a Machinable Feature to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example associates in firstOperation the machinable
                |         feature Feature
                | 
                |          call firstOperation.SetFeature(Feature)

        :param AnyObject i_machinable_feature:
        :rtype: None
        """
        return self.manufacturing_operation.SetFeature(i_machinable_feature.com_object)

    def set_feed_speed_auto_update(self, i_type: str, i_auto_update: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFeedSpeedAutoUpdate(CATBSTR iType,
                | boolean iAutoUpdate)
                | 
                |     Set the Auto Update status for Feed Rate or Spindle Speed.
                | 
                |     Parameters:
                | 
                |         iType
                |             Determines if the method works on Feed Rate or Spindle Speed Legal
                |             values: iType can be
                | 
                |                 "FEEDRATE"
                |                 "SPINDLESPEED"
                | 
                |         iAutoUpdate
                |             Auto update status Legal values: iType can be
                | 
                |                 True
                |                 False
                | 
                |                     Example:
                |                     The following example enables AutoUpdate for Spindle
                |                     Speed
                |                     firstOperation.SetFeedSpeedAutoUpdate("SPINDLESPEED",
                |                     True)

        :param str i_type:
        :param bool i_auto_update:
        :rtype: None
        """
        return self.manufacturing_operation.SetFeedSpeedAutoUpdate(i_type, i_auto_update)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_feed_speed_auto_update'
        # # vba_code = """
        # # Public Function set_feed_speed_auto_update(manufacturing_operation)
        # #     Dim iType (2)
        # #     manufacturing_operation.SetFeedSpeedAutoUpdate iType
        # #     set_feed_speed_auto_update = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_feedrate_magnitude(self, i_magnitude_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFeedrateMagnitude(CATBSTR iMagnitudeName)
                | 
                |     Defines the magnitude of the feedrate values.
                | 
                |      
                | 
                |          
                |         The available types for Magnitude are: 
                |          
                |         for Linear Magnitude , iMagnitudeName = LINEARFEEDRATE
                |          
                |         for Angular Magnitude , iMagnitudeName = ANGULARFEEDRATE
                |          
                |     Example:
                |      Dim Operation1 As ManufacturingOperation
                |      Set Operation1 = Program1.AppendOperation ("Drilling",1)
                |      Operation1.SetFeedrateMagnitude("LINEARFEEDRATE")

        :param str i_magnitude_name:
        :rtype: None
        """
        return self.manufacturing_operation.SetFeedrateMagnitude(i_magnitude_name)

    def set_geometry(self, i_geometry_type: str, i_reference: AnyObject, i_product: AnyObject, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGeometry(CATBSTR iGeometryType,
                | AnyObject iReference,
                | AnyObject iProduct,
                | short iPosition)
                | 
                |     Assigns geometry to a Manufacturing Operation.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Type of geometry to assign List of valid iGeometryType: - Parts -
                |             Drives - RoughStock - PartBottom - Checks - GuidingCurves - FirstGuideLine -
                |             SecondGuideLine - AuxGuidingCurves - RelimitingFace - RelimitingPlane -
                |             FirstRelimitingElement - SecondRelimitingElement - EndingPoint - StartingPoint
                |             - Island - SetupStocks - SetupDesigns 
                |         iReference
                |             Geometry to assign: it may be a feature (point, hole, ...) or a
                |             BREP feature. 
                |         iProduct
                |             Product containing the geometry to assign. It must be the occurence
                |             of the product which owns the part containing the geometry. Also see method
                |             GetProductInstance of CATIAManufacturingSetup interface.
                |             
                |         iPosition
                |             Position of the geometry in the list (0 to append at the end of the
                |             list). 
                |         Example:
                |             The following example assigns the plane Plane.1 as bottom of
                |             operation Pocketing1 of the Manufacturing Program Program1. The Product
                |             Product1 is associated to Manufacturing Setup Setup1. This example is valid
                |             only if the Product owning the part which contains the plane has been
                |             associated to the Manufacturing Setup (if the CATPart containing the plane has
                |             been associated to the Manufacturing Setup). In other cases, the product must
                |             be retrieved differently.
                | 
                |              Set Product1 = Setup1.GetProductInstance()
                |              Dim Pocketing1 As ManufacturingOperation
                |              Set Pocketing1 = Program1.AppendOperation ("Pocketing",1)
                |              Pocketing1
                |              .SetGeometry("PartBottom",Plane1,Product1,0)

        :param str i_geometry_type:
        :param AnyObject i_reference:
        :param AnyObject i_product:
        :param int i_position:
        :rtype: None
        """
        return self.manufacturing_operation.SetGeometry(
            i_geometry_type,
            i_reference.com_object,
            i_product.com_object,
            i_position
        )

    def set_pattern(self, i_pattern: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPattern(AnyObject iPattern)
                | 
                |     Associate a Machining Pattern to a Manufacturing
                |     Operation.
                | 
                |     Example:
                |         The following example associates in firstOperation the machining
                |         pattern Pattern
                | 
                |          call firstOperation.SetPattern(Pattern)

        :param AnyObject i_pattern:
        :rtype: None
        """
        return self.manufacturing_operation.SetPattern(i_pattern.com_object)

    def set_radius_on_macro(self, i_macro_type: str, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRadiusOnMacro(CATBSTR iMacroType,
                | double iRadius)
                | 
                |     Defines radius attribute on the circular elementary macro motion on
                |     CIRCULAR MILLING or THREAD MILLING operations ONLY.
                | 
                |     Parameters:
                | 
                |         iMacroType
                |             Legal values: iMacroType can be:
                | 
                |             "Approach", to set the radius on the Approach
                |             Macro
                |             "Retract", to set the radius on the Retract Macro
                |             "ReturnInALevelApproach", to set the radius on the Return in a
                |             level Macro (Approach)
                |             "ReturnInALevelRetract", to set the radius on the Return in a level
                |             Macro (Retract)
                |             "ReturnBetweenLevelsApproach", to set the radius on the Return
                |             between levels Macro (Approach)
                |             "ReturnBetweenLevelsRetract", to set the radius on the Return
                |             between levels Macro (Approach)
                | 
                |         iRadius
                |             Radius value. (expressed in millimeters) 
                | 
                |     Example:
                |         The following example sets a radius 5mm on the circular motion of the
                |         retract macro on the Circular Milling operation
                |         CircularMilling1
                | 
                |          Dim CircularMilling1 As ManufacturingOperation
                |          Set CircularMilling1 = Program1.AppendOperation ("CircularMilling1",1)
                |          Call
                |          CircularMilling1.SetRadiusOnMacro("Retract",5.00)

        :param str i_macro_type:
        :param float i_radius:
        :rtype: None
        """
        return self.manufacturing_operation.SetRadiusOnMacro(i_macro_type, i_radius)

    def set_relimiting_geometry(
            self,
            i_geometry_type: str,
            i_reference: AnyObject,
            i_product: AnyObject,
            i_offset: float,
            i_position: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRelimitingGeometry(CATBSTR iGeometryType,
                | AnyObject iReference,
                | AnyObject iProduct,
                | double iOffset,
                | CATBSTR iPosition)
                | 
                |     Defines start / end element on PROFILE CONTOURING operation
                |     ONLY.
                |     Sets a geometry on relimiting element in profile contouring
                |     operation.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be:
                | 
                |             "StartElement", to set the Start element on Profile
                |             Contouring
                |             "EndElement", to set the End element on Profile
                |             Contouring
                | 
                |         iReference
                |             Geometries to be set. It can be a list of curves or a single point.
                |             The curves must be adjacent. 
                |         iProduct
                |             Product containing the geometry to be set. 
                |         iOffset
                |             Offset to set on the relimiting geometry. (expressed in
                |             millimeters) 
                |         iPosition
                |             Tool position to set on the relimiting geometry.
                |             Legal values: iPosition can be:
                | 
                |             "IN", to set the tool position IN
                |             "ON", to set the tool position ON
                |             "OUT", to set the tool position OUT
                | 
                |     Example:
                |         The following example sets the Start relimiting element Curve1 on the
                |         Profile Contouring operation Contouring1
                | 
                |          Call Contouring1.SetRelimitingGeometry("StartElement",Curve1,PartMachined,3.00,"ON")

        :param str i_geometry_type:
        :param AnyObject i_reference:
        :param AnyObject i_product:
        :param float i_offset:
        :param str i_position:
        :rtype: None
        """
        return self.manufacturing_operation.SetRelimitingGeometry(
            i_geometry_type,
            i_reference.com_object,
            i_product.com_object,
            i_offset,
            i_position
        )

    def set_spindle_magnitude(self, i_magnitude_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpindleMagnitude(CATBSTR iMagnitudeName)
                | 
                |     Defines the magnitude of the spindle values.
                |
                |         The available types for Magnitude are: 
                |          
                |         for Linear Magnitude , iMagnitudeName = LINEARSPINDLESPEED
                |          
                |         for Angular Magnitude , iMagnitudeName = ANGULARSPINDLESPEED
                |          
                |     Example:
                |      Dim Operation1 As ManufacturingOperation
                |      Set Operation1 = Program1.AppendOperation ("Drilling",1)
                |      Operation1.SetSpindleMagnitude("ANGULARSPINDLESPEED")

        :param str i_magnitude_name:
        :rtype: None
        """
        return self.manufacturing_operation.SetSpindleMagnitude(i_magnitude_name)

    def set_start_point_geometry(
            self,
            i_geometry_position: str,
            i_reference: AnyObject,
            i_product: AnyObject,
            i_offset: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStartPointGeometry(CATBSTR iGeometryPosition,
                | AnyObject iReference,
                | AnyObject iProduct,
                | double iOffset)
                | 
                |     Defines the geometry and the offset of a start point on POCKETING operation
                |     ONLY.
                | 
                |     Parameters:
                | 
                |         iGeometryPosition
                |             Legal values: iGeometryPosition can be:
                | 
                |             "Outside", to set the Start point outside the pocket
                |             contour
                |             "Inside", to set the Start point inside the pocket
                |             contour
                | 
                |         iReference
                |             Geometry to be set. It can be a point. 
                |         iProduct
                |             Product containing the geometry to be set. 
                |         iOffset
                |             Offset set on the start point. (expressed in
                |             millimeters)
                |             Offset is taken into account only if iGeometryPosition is set to
                |             "Outside". 
                | 
                |     Example:
                |         The following example sets Point1 as Start point on the Pocketing
                |         operation Pocketing1
                | 
                |          Call Pocketing1.SetStartPointGeometry("Inside",Point1,PartMachined,0.00)

        :param str i_geometry_position:
        :param AnyObject i_reference:
        :param AnyObject i_product:
        :param float i_offset:
        :rtype: None
        """
        return self.manufacturing_operation.SetStartPointGeometry(
            i_geometry_position,
            i_reference.com_object,
            i_product.com_object,
            i_offset
        )

    def set_tool(self, i_tool_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTool(CATBSTR iToolName)
                | 
                |     Assign an already created tool to a Manufacturing
                |     Operation.
                |     If the tool is not already created, or if it is not authorized for this
                |     kind of Manufacturing Operation, a default tool is
                |     created.
                | 
                |     Example:
                |         The following example assign a drill tool named D-9.7 on the operation
                |         MO1 of the Manufacturing Program Program1 A tool change with tool D-9.7 has
                |         already been created in the Manufacturing Program.
                | 
                |          Dim Operation1 As ManufacturingOperation
                |          Set Operation1 = Program1.AppendOperation ("Drilling",1)
                |          Operation1.SetTool("D-9.7")

        :param str i_tool_name:
        :rtype: None
        """
        return self.manufacturing_operation.SetTool(i_tool_name)

    def unlock_activity(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnlockActivty()

        :rtype: None
        """
        return self.manufacturing_operation.UnlockActivty()

    def __repr__(self):
        return f'ManufacturingOperation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.robot_task import RobotTask
from pycatia.system_interfaces.any_object import AnyObject


class RobotTaskFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RobotTaskFactory
                | 
                | Represents the Task Creation Factory for Robots.
                | 
                | Role: Robot Task Factory is the object used to create robot
                | tasks.
                | The following code snippet can be used to obtain the Robot Task Factory from
                | the robot product.
                | 
                |    Dim objRobotTaskFactory As RobotTaskFactory
                |    Dim objRobot As Product
                |    ...
                |    Set objRobotTaskFactory = objRobot.GetTechnologicalObject("RobotTaskFactory" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.robot_task_factory = com_object

    def create_robot_task(self, i_name: str, o_robot_task: RobotTask) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateRobotTask(CATBSTR iName,
                | RobotTask oRobotTask)
                | 
                |     Creates a Robot Task
                | 
                |     Parameters:
                | 
                |         iName
                |             The Robot Task Name. 
                |         oRobotTask
                |             The Created Robot Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Robot Task was successfully created.
                |         E_FAIL
                |             The Robot Task creation failed.
                | 
                |         Example:
                |             The following example creates a robot task for a
                |             robot.
                | 
                |                Dim objRobotTaskFactory As RobotTaskFactory
                |                Dim objRobotTask as RobotTask
                |                ..
                |                objRobotTaskFactory.CreateRobotTask
                |                "New_RobotTask_1",objRobotTask

        :param str i_name:
        :param RobotTask o_robot_task:
        :rtype: None
        """
        return self.robot_task_factory.CreateRobotTask(i_name, o_robot_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_robot_task'
        # # vba_code = """
        # # Public Function create_robot_task(robot_task_factory)
        # #     Dim iName (2)
        # #     robot_task_factory.CreateRobotTask iName
        # #     create_robot_task = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_robot_task(self, i_robot_task: RobotTask) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteRobotTask(RobotTask iRobotTask)
                | 
                |     Removes the required Robot Task.
                | 
                |     Parameters:
                | 
                |         iRobotTask
                |             The Robot Task to be Removed. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Robot Task could be successfully deleted.
                |         E_FAIL
                |             The deletion of Robot Task failed.
                | 
                |         Example:
                |             The following example deleted a robot task of a
                |             robot.
                | 
                |                Dim objRobotTaskFactory As RobotTaskFactory
                |                Dim objRobotTask as RobotTask
                |                ..
                |                objRobotTaskFactory.DeleteRobotTask
                |                objRobotTask

        :param RobotTask i_robot_task:
        :rtype: None
        """
        return self.robot_task_factory.DeleteRobotTask(i_robot_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_robot_task'
        # # vba_code = """
        # # Public Function delete_robot_task(robot_task_factory)
        # #     Dim iRobotTask (2)
        # #     robot_task_factory.DeleteRobotTask iRobotTask
        # #     delete_robot_task = iRobotTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_all_robot_tasks(self, o_robot_task_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllRobotTasks(CATSafeArrayVariant oRobotTaskList)
                | 
                |     Retrieves the list of Robot Tasks owned by a Robot.
                | 
                |     Parameters:
                | 
                |         oRobotTaskList
                |             The Robot Task List. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Robot Task List could be successfully queried.
                |         E_FAIL
                |             The Robot Task List could not be retrieved.
                | 
                |         Example:
                |             The following example Retrieves the list of Robot Tasks for the
                |             Robot.
                | 
                |                Dim objRobotTaskFactory As RobotTaskFactory
                |                Dim objRobotTask(3) as RobotTask
                |                ..
                |                objRobotTaskFactory.GetAllRobotTasks
                |                objRobotTask

        :param tuple o_robot_task_list:
        :rtype: None
        """
        return self.robot_task_factory.GetAllRobotTasks(o_robot_task_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_robot_tasks'
        # # vba_code = """
        # # Public Function get_all_robot_tasks(robot_task_factory)
        # #     Dim oRobotTaskList (2)
        # #     robot_task_factory.GetAllRobotTasks oRobotTaskList
        # #     get_all_robot_tasks = oRobotTaskList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RobotTaskFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_object import SFMObject
from pycatia.cat_str_functional_interfaces.sfm_slots import SFMSlots
from pycatia.cat_str_functional_interfaces.sfm_split_plates import SFMSplitPlates
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.types.general import cat_variant


class SFMSuperPlate(SFMObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         SfmSuperPlate
                | 
                | Interface to manage the Structure Functional Modeler SuperPlate
                | object.
                | Role: Allows accessing and setting of SuperPlate's data.
                | 
                | See also:
                |     SfmFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_super_plate = com_object

    @property
    def limit_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LimitMode() As long
                | 
                |     Returns or sets the SuperPlate's limit mode.
                | 
                |     Example:
                |         This example retrieves in LimitMode the limit mode of the SuperPlate
                |         feature.
                | 
                |          Dim LimitMode As Integer
                |          Set LimitMode = SuperPlate.LimitMode

        :rtype: int
        """

        return self.sfm_super_plate.LimitMode

    @limit_mode.setter
    def limit_mode(self, value: int):
        """
        :param int value:
        """

        self.sfm_super_plate.LimitMode = value

    @property
    def molded_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoldedSurface() As Reference (Read Only)
                | 
                |     Returns the molded surface.
                | 
                |     Example:
                |         This example retrieves in MoldedSurface the molded surface for the
                |         SuperPlate feature.
                | 
                |          Dim MoldedSurface As Reference
                |          Set MoldedSurface = SuperPlate.MoldedSurface

        :rtype: Reference
        """

        return Reference(self.sfm_super_plate.MoldedSurface)

    @property
    def split_plates(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplitPlates() As References (Read Only)
                | 
                |     Returns the SplitPlates.
                | 
                |     Example:
                |         This example retrieves in SplitPlates the list of SplitPlates for the
                |         SuperPlate feature.
                | 
                |          Dim SplitPlates As References
                |          Set SplitPlates = SuperPlate.SplitPlates

        :rtype: References
        """

        return References(self.sfm_super_plate.SplitPlates)

    @property
    def split_plates_objects(self) -> SFMSplitPlates:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplitPlatesObjects() As SfmSplitPlates (Read Only)
                | 
                |     Returns the SplitPlates.
                | 
                |     Example:
                |         This example retrieves in SplitPlates the list of SplitPlates for the
                |         SuperPlate feature.
                | 
                |          Dim SuperPlate2 As SfmSuperPlate
                |          Set SuperPlate2 = SuperPlates.Item(2)
                |          Dim OperatedSuperPlateObject  As SfmSuperPlateObject
                |          Set OperatedSuperPlateObject = SuperPlate2.GetItem("SfmSuperPlateObject")
                |          Dim SplitPlates As SplitPlatesObjects
                |          Set SplitPlates = SuperPlate.SplitPlatesObjects

        :rtype: SFMSplitPlates
        """

        return SFMSplitPlates(self.sfm_super_plate.SplitPlatesObjects)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Support() As Reference
                | 
                |     Returns the SuperPlate's support.
                | 
                |     Example:
                |         This example retrieves in Support the support of the SuperPlate
                |         feature.
                | 
                |          Dim Support As Reference
                |          Set Support = SuperPlate.Support

        :rtype: Reference
        """

        return Reference(self.sfm_super_plate.Support)

    @support.setter
    def support(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_super_plate.Support = value.com_object

    @property
    def support_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SupportOffset() As double
                | 
                |     Returns or sets the SuperPlate's support offset.
                | 
                |     Example:
                |         This example retrieves in Offset the support offset of the SuperPlate
                |         feature.
                | 
                |          Dim Offset As Double
                |          Set Offset = SuperPlate.SupportOffset

        :rtype: float
        """

        return self.sfm_super_plate.SupportOffset

    @support_offset.setter
    def support_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_super_plate.SupportOffset = value

    @property
    def support_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SupportOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_super_plate.SupportOffsetParam)

    @property
    def thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Thickness() As double
                | 
                |     Returns or sets the SuperPlate's Thickness.
                | 
                |     Example:
                |         This example retrieves the Thickness of existing
                |         SuperPlate.
                | 
                |          Dim ThicknessValue As Double
                |          Set ThicknessValue = SuperPlate.Thickness

        :rtype: float
        """

        return self.sfm_super_plate.Thickness

    @thickness.setter
    def thickness(self, value: float):
        """
        :param float value:
        """

        self.sfm_super_plate.Thickness = value

    def add_limit(self, i_limit: Reference, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddLimit(Reference iLimit,
                | long iOrientation)
                | 
                |     Adds one object to the list of connected object.
                | 
                |     Parameters:
                | 
                |         iLimit
                |             [in] New Limit to add. 
                |         iOrientation
                |             [in] iOrientation value can be selected from
                |                  InvertOrientation = -1,
                |                  UnknownOrientation = 0,
                |                  SameOrientation = 1,
                |                  GlobalOrientation(Xp) = 2,
                |                  GlobalOrientation(Xm) = 3,
                |                  GlobalOrientation(Yp) = 4,
                |                  GlobalOrientation(Ym) = 5,
                |                  GlobalOrientation(Zp) = 6,
                |                  GlobalOrientation(Zm) = 7,
                |                  GlobalOrientation_Inside = 8,
                |                  [SameOrientation ] GlobalOrientation_Outside = 9,
                |                  [InvertOrientation ] GlobalOrientation_LInboard = 10
                |                  [Toward center line] GlobalOrientation_LOutboard = 11
                |                  [Opposite of previous one ] GlobalOrientation_TInboard = 12 [Toward midship ]
                |                  GlobalOrientation_TOutboard = 13 [Opposite of previous one]
                | 
                |             Example:
                |                 This example adds one limit to Deck Plate, and keeps Fore
                |                 Side.
                | 
                |                  Set PlateLimit = ObjPart.FindObjectByName("CROSS.60")
                |                  Dim LimitRef As Reference
                |                  Set LimitRef = ObjPart.CreateReferenceFromObject(PlateLimit)
                |                  Dim Orientation As Long
                |                  Orientation = 2
                |                  SuperPlate.AddLimit LimitRef, Orientation

        :param Reference i_limit:
        :param int i_orientation:
        :rtype: None
        """
        return self.sfm_super_plate.AddLimit(i_limit.com_object, i_orientation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_limit'
        # # vba_code = """
        # # Public Function add_limit(sfm_super_plate)
        # #     Dim iLimit (2)
        # #     sfm_super_plate.AddLimit iLimit
        # #     add_limit = iLimit
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_free_edges(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFreeEdges() As References
                | 
                |     Returns the Free Edges of Super Plate.
                | 
                |     Example:
                |         This example retrieves in FreeEdges the list of free edges for the
                |         SuperPlate feature.
                | 
                |           
                |         Dim FreeEdges As References
                |         Set FreeEdges = SuperPlate.GetFreeEdges

        :rtype: References
        """
        return References(self.sfm_super_plate.GetFreeEdges())

    def get_slots_on_plate(self) -> SFMSlots:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSlotsOnPlate() As SfmSlots
                | 
                |     Retrieves Slots on Plate.
                | 
                |     Parameters:
                | 
                |         oSfmSlots
                |             [out] Slots. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets the Slots.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = PlateObj.GetSlotsOnPlate

        :rtype: SFMSlots
        """
        return SFMSlots(self.sfm_super_plate.GetSlotsOnPlate())

    def get_split_plate_attributes(
            self,
            i_split_plate_number: int,
            o_thickness: float,
            o_material_name: str,
            o_grade_name: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSplitPlateAttributes(long iSplitPlateNumber,
                | double oThickness,
                | CATBSTR oMaterialName,
                | CATBSTR oGradeName)
                | 
                |     Returns the SplitPlate(ChildPlate)
                |     Attributes(Thickness,Material,Grade).
                | 
                |     Parameters:
                | 
                |         iSplitPlateNumber
                |             [in] This Number is the Split Plate number desired.
                |             
                |         oThickness
                |             [out] Thickness of the child Plate. 
                |         oMaterialName
                |             [out] Material of the child Plate. 
                |         oGradeName
                |             [out] Grade of the child Plate.
                | 
                |             Example:
                |                 This example retrieves the attributes of the
                |                 ChildPlate.
                | 
                |                  'Retrieve the Split Plates under the
                |                  SuperPlate
                |                  Dim SplitPlates as References
                |                  Set SplitPlates = SuperPlateObj.SplitPlates
                |                  Dim SplitPlate1 As Reference
                |                  Set SplitPlate1 = SplitPlates.Item(1)
                |                  'Add the Split Plate to Selection
                |                  Set SelctionObj = CATIA.ActiveDocument.Selection
                |                  SelctionObj.Add SplitPlate1
                |                  'Retrieve the Split Plate From Selection
                |                  Dim SplitPlateObj As SfmSuperPlate
                |                  Set SplitPlateObj = SelctionObj.FindObject("CATIASfmSuperPlate")
                |                  Dim Thickness As Double
                |                  Dim Material As String
                |                  Dim Grade As String    
                |                  SplitPlateObj.GetSplitPlateAttributes 1, Thickness ,Material
                |                  ,Grade

        :param int i_split_plate_number:
        :param float o_thickness:
        :param str o_material_name:
        :param str o_grade_name:
        :rtype: None
        """
        return self.sfm_super_plate.GetSplitPlateAttributes(
            i_split_plate_number,
            o_thickness,
            o_material_name,
            o_grade_name
        )

    def invert_limit(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertLimit(CATVariant iIndex)
                | 
                |     Invert a limit orientation by its index or its name.
                | 
                |     Example:
                |         This example removes the first object from the list of connected
                |         objects for the StfConnection feature.
                | 
                |          StfConnection.RemoveObject 1

        :param cat_variant i_index:
        :rtype: None
        """
        return self.sfm_super_plate.InvertLimit(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'invert_limit'
        # # vba_code = """
        # # Public Function invert_limit(sfm_super_plate)
        # #     Dim iIndex (2)
        # #     sfm_super_plate.InvertLimit iIndex
        # #     invert_limit = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def limit_orientations(self, io_orientations: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LimitOrientations(CATSafeArrayVariant ioOrientations)
                | 
                |     Returns the orientation of the limits.
                | 
                |     Example:
                |         This example retrieves in Orientations the list of orientations limit
                |         for the SuperPlate feature.
                | 
                |          Dim Orientations As References
                |          SuperPlate.LimitOrientations Orientations

        :param tuple io_orientations:
        :rtype: None
        """
        return self.sfm_super_plate.LimitOrientations(io_orientations)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'limit_orientations'
        # # vba_code = """
        # # Public Function limit_orientations(sfm_super_plate)
        # #     Dim ioOrientations (2)
        # #     sfm_super_plate.LimitOrientations ioOrientations
        # #     limit_orientations = ioOrientations
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def limits(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Limits() As References
                | 
                |     Returns the limits.
                | 
                |     Example:
                |         This example retrieves in Limits the list of limits for the SuperPlate
                |         feature.
                | 
                |          Dim Limits As References
                |          SuperPlate.Limits Limits, Orientations

        :rtype: References
        """
        return References(self.sfm_super_plate.Limits())

    def remove_limit(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveLimit(CATVariant iIndex)
                | 
                |     Removes one object from the list of limits by its index or its
                |     name.
                | 
                |     Example:
                |         This example removes the first object from the list of connected
                |         objects for the StfConnection feature.
                | 
                |          StfConnection.RemoveObject 1

        :param cat_variant i_index:
        :rtype: None
        """
        return self.sfm_super_plate.RemoveLimit(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_limit'
        # # vba_code = """
        # # Public Function remove_limit(sfm_super_plate)
        # #     Dim iIndex (2)
        # #     sfm_super_plate.RemoveLimit iIndex
        # #     remove_limit = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def run(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Run()
                | 
                |     Build the SplitPlates.
                | 
                |     Example:
                |         This example build the SplitPlates for the SuperPlate
                |         feature.
                | 
                |          SuperPlate.Run

        :rtype: None
        """
        return self.sfm_super_plate.Run()

    def set_as_last_limit(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAsLastLimit(CATVariant iIndex)
                | 
                |     Adds one limit at the end of the list.
                | 
                |     Example:
                |         This example sets the limit at the end of the list of
                |         limits.
                | 
                |          SuperPlate.SetAsLastLimit Index

        :param cat_variant i_index:
        :rtype: None
        """
        return self.sfm_super_plate.SetAsLastLimit(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_as_last_limit'
        # # vba_code = """
        # # Public Function set_as_last_limit(sfm_super_plate)
        # #     Dim iIndex (2)
        # #     sfm_super_plate.SetAsLastLimit iIndex
        # #     set_as_last_limit = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_split_plate_attributes(
            self,
            i_split_plate_number: int,
            i_thickness: float,
            i_material_name: str,
            i_grade_name: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSplitPlateAttributes(long iSplitPlateNumber,
                | double iThickness,
                | CATBSTR iMaterialName,
                | CATBSTR iGradeName)
                | 
                |     Set the SplitPlate(ChildPlate)
                |     Attributes(Thickness,Material,Grade).
                | 
                |     Parameters:
                | 
                |         iSplitPlateNumber
                |             [in] iSplitPlateNumber will be 1,2,3... 
                |         iThickness
                |             [in] Thickness of the child Plate. 
                |         iMaterialName
                |             [in] Material of the child Plate. 
                |         iGradeName
                |             [in] Grade of the child Plate.
                | 
                |             Example:
                |                 This example sets the attributes of the
                |                 ChildPlate.
                | 
                |                  'Retrieve the Split Plates under the
                |                  SuperPlate
                |                  Dim SplitPlates as References
                |                  Set SplitPlates = SuperPlateObj.SplitPlates
                |                  Dim SplitPlate1 As Reference
                |                  Set SplitPlate1 = SplitPlates.Item(1)
                |                  'Add the Split Plate to Selection
                |                  Set SelctionObj = CATIA.ActiveDocument.Selection
                |                  SelctionObj.Add SplitPlate1
                |                  'Retrieve the Split Plate From Selection
                |                  Dim SplitPlateObj As SfmSuperPlate
                |                  Set SplitPlateObj = SelctionObj.FindObject("CATIASfmSuperPlate")
                |                  SplitPlateObj.SetSplitPlateAttributes 1, 30, "Steel",
                |                  "A45"

        :param int i_split_plate_number:
        :param float i_thickness:
        :param str i_material_name:
        :param str i_grade_name:
        :rtype: None
        """
        return self.sfm_super_plate.SetSplitPlateAttributes(
            i_split_plate_number,
            i_thickness,
            i_material_name,
            i_grade_name
        )

    def __repr__(self):
        return f'SFMSuperPlate(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AssemblyGeneralSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AsmGeneralSettingAtt
                | 
                | Represents the Assembly General setting controller object.
                | Role: the Assembly General setting controller object deals with the setting
                | parameters displayed in the Assembly General property page. To access this
                | property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of Mechanical Design to unfold the workbench
                |     list
                |     Click Assembly Design: General tab
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_general_setting_att = com_object

    @property
    def auto_switch_to_design_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoSwitchToDesignMode() As
                | CatAsmAutoSwitchToDesignMode
                | 
                |     Returns or sets the implicit switch from visualization mode to design mode
                |     setting parameter .
                |     Role: The implicit switch from visualization mode to design mode setting
                |     parameter manages the loading of necessayr data whenever they are needed. Note
                |     that this option is useful only when the Cache option is
                |     activated
                |     Legal values:
                |     catAutoSwitchUnavailable Automatic switch to design mode
                |     unavailable
                |     catAutoSwitchAvailable Automatic switch to design mode
                |     available
                | 
                |     Example:
                |         The following example retrieves the implicit switch setting parameter
                |         of AsmGeneralSettingAtt1 in SwitchMode and enables the
                |         switch
                | 
                |          Set SwitchMode = AsmGeneralSettingAtt1.AutoSwitchToDesignMode
                |          AsmGeneralSettingAtt1.AutoSwitchToDesignMode = catAutoSwitchAvailable

        :return: enum cat_asm_auto_switch_to_design_mode
        :rtype: int
        """

        return self.assembly_general_setting_att.AutoSwitchToDesignMode

    @auto_switch_to_design_mode.setter
    def auto_switch_to_design_mode(self, value: int):
        """
        :param int value: enum cat_asm_auto_switch_to_design_mode
        """

        self.assembly_general_setting_att.AutoSwitchToDesignMode = value

    @property
    def auto_update_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoUpdateMode() As CatAsmUpdateMode
                | 
                |     Returns or sets the automatic update setting parameter.
                |     Role: The automatic update setting parameter manages the automatic
                |     launching of the Update command.
                |     Legal values:
                |     catManualUpdate Manual update mode
                |     catAutomaticUpdate Automatic update mode
                | 
                |     Example:
                |         The following example retrieves the automatic update setting parameter
                |         of AsmGeneralSettingAtt1 in UpdateMode and sets the mode to manual
                |         update.
                | 
                |          Set UpdateMode = AsmGeneralSettingAtt1.AutoUpdateMode
                |          AsmGeneralSettingAtt1.AutoUpdateMode = catManualUpdate

        :return: enum cat_asm_update_mode
        :rtype: int
        """

        return self.assembly_general_setting_att.AutoUpdateMode

    @auto_update_mode.setter
    def auto_update_mode(self, value: int):
        """
        :param int value: enum cat_asm_update_mode
        """

        self.assembly_general_setting_att.AutoUpdateMode = value

    @property
    def move_with_fix_t_extend_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoveWithFixTExtendMode() As CatAsmExtendMoveToFixT
                | 
                |     Returns or sets the setting parameter managing the extension of a move to
                |     the components involved in a FixTogether.
                |     Role: This setting parameter manages whether the components involved in a
                |     FixTogether will be moved or not.
                |     Legal values:
                |     catNeverExtendMoveToFixT Never extend move to all component involved in a
                |     FixTogether
                |     catAskIfExtendMoveToFixT Ask question to extend move to all component
                |     involved in a FixTogether
                |     catAlwaysExtendMoveToFixT Always extend move to all component involved in
                |     a FixTogether
                | 
                |     Example:
                |         The following example retrieves the move setting parameter of
                |         AsmGeneralSettingAtt1 in MoveMode and sets it to
                |         Always
                | 
                |          Set MoveMode = AsmGeneralSettingAtt1.MoveWithFixTExtendMode
                |          AsmGeneralSettingAtt1.MoveWithFixTExtendMode = catAlwaysExtendMoveToFixT

        :return: enum cat_asm_extend_move_to_fix_t
        :rtype: int
        """

        return self.assembly_general_setting_att.MoveWithFixTExtendMode

    @move_with_fix_t_extend_mode.setter
    def move_with_fix_t_extend_mode(self, value: int):
        """
        :param int value:
        """

        self.assembly_general_setting_att.MoveWithFixTExtendMode = value

    @property
    def update_status_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UpdateStatusMode() As
                | CatAsmUpdateStatusComputeMode
                | 
                |     Returns or sets the update status computation setting
                |     parameter.
                |     Role: The update status computation setting parameter manages the loading
                |     at open of the data necessary to the exact update status computation. Note that
                |     this option is useful only when the Cache option is
                |     activated
                |     Legal values:
                |     catManualCompute At open the update status is unknown
                |     catAutomaticCompute Additional data are being loaded at open to compute an
                |     exact Update status
                | 
                |     Example:
                |         The following example retrieves the update status computation setting
                |         parameter of AsmGeneralSettingAtt1 in StatusMode and sets the mode to automatic
                |         computation.
                | 
                |          Set StatusMode = AsmGeneralSettingAtt1.UpdateStatusMode
                |          AsmGeneralSettingAtt1.UpdateStatusMode = catAutomaticCompute

        :return: enum cat_asm_update_status_compute_mode
        :rtype: int
        """

        return self.assembly_general_setting_att.UpdateStatusMode

    @update_status_mode.setter
    def update_status_mode(self, value: int):
        """
        :param int value: enum cat_asm_update_status_compute_mode
        """

        self.assembly_general_setting_att.UpdateStatusMode = value

    def get_auto_switch_to_design_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoSwitchToDesignModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves the state of the implicit switch from visualization mode to
                |     design mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.assembly_general_setting_att.GetAutoSwitchToDesignModeInfo(admin_level, o_locked)

    def get_auto_update_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoUpdateModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves informations about the automatic update setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.assembly_general_setting_att.GetAutoUpdateModeInfo(io_admin_level, io_locked)

    def get_move_with_fix_t_extend_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMoveWithFixTExtendModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves the state of the setting parameter managing the extension of a
                |     move to the components involved in a FixTogether.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.assembly_general_setting_att.GetMoveWithFixTExtendModeInfo(admin_level, o_locked)

    def get_update_status_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUpdateStatusModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves informations about the update status computation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.assembly_general_setting_att.GetUpdateStatusModeInfo(admin_level, o_locked)

    def set_auto_switch_to_design_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoSwitchToDesignModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the implicit switch from visualization mode to design mode
                |     setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_general_setting_att.SetAutoSwitchToDesignModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_switch_to_design_mode_lock'
        # # vba_code = """
        # # Public Function set_auto_switch_to_design_mode_lock(asm_general_setting_att)
        # #     Dim iLocked (2)
        # #     asm_general_setting_att.SetAutoSwitchToDesignModeLock iLocked
        # #     set_auto_switch_to_design_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_auto_update_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoUpdateModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the automatic update setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_general_setting_att.SetAutoUpdateModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_update_mode_lock'
        # # vba_code = """
        # # Public Function set_auto_update_mode_lock(asm_general_setting_att)
        # #     Dim iLocked (2)
        # #     asm_general_setting_att.SetAutoUpdateModeLock iLocked
        # #     set_auto_update_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_move_with_fix_t_extend_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMoveWithFixTExtendModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the setting parameter managing the extension of a move to
                |     the components involved in a FixTogether.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_general_setting_att.SetMoveWithFixTExtendModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_move_with_fix_t_extend_mode_lock'
        # # vba_code = """
        # # Public Function set_move_with_fix_t_extend_mode_lock(asm_general_setting_att)
        # #     Dim iLocked (2)
        # #     asm_general_setting_att.SetMoveWithFixTExtendModeLock iLocked
        # #     set_move_with_fix_t_extend_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_update_status_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUpdateStatusModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the update status computation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.assembly_general_setting_att.SetUpdateStatusModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_update_status_mode_lock'
        # # vba_code = """
        # # Public Function set_update_status_mode_lock(asm_general_setting_att)
        # #     Dim iLocked (2)
        # #     asm_general_setting_att.SetUpdateStatusModeLock iLocked
        # #     set_update_status_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyGeneralSettingAtt(name="{self.name}")'
